
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer HECMW_ctrl_create_buffer
#define yy_delete_buffer HECMW_ctrl_delete_buffer
#define yy_flex_debug HECMW_ctrl_flex_debug
#define yy_init_buffer HECMW_ctrl_init_buffer
#define yy_flush_buffer HECMW_ctrl_flush_buffer
#define yy_load_buffer_state HECMW_ctrl_load_buffer_state
#define yy_switch_to_buffer HECMW_ctrl_switch_to_buffer
#define yyin HECMW_ctrlin
#define yyleng HECMW_ctrlleng
#define yylex HECMW_ctrllex
#define yylineno HECMW_ctrllineno
#define yyout HECMW_ctrlout
#define yyrestart HECMW_ctrlrestart
#define yytext HECMW_ctrltext
#define yywrap HECMW_ctrlwrap
#define yyalloc HECMW_ctrlalloc
#define yyrealloc HECMW_ctrlrealloc
#define yyfree HECMW_ctrlfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE HECMW_ctrlrestart(HECMW_ctrlin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t HECMW_ctrlleng;

extern FILE *HECMW_ctrlin, *HECMW_ctrlout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up HECMW_ctrltext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up HECMW_ctrltext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via HECMW_ctrlrestart()), so that the user can continue scanning by
	 * just pointing HECMW_ctrlin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when HECMW_ctrltext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t HECMW_ctrlleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow HECMW_ctrlwrap()'s to do buffer switches
 * instead of setting up a fresh HECMW_ctrlin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void HECMW_ctrlrestart (FILE *input_file  );
void HECMW_ctrl_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE HECMW_ctrl_create_buffer (FILE *file,int size  );
void HECMW_ctrl_delete_buffer (YY_BUFFER_STATE b  );
void HECMW_ctrl_flush_buffer (YY_BUFFER_STATE b  );
void HECMW_ctrlpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void HECMW_ctrlpop_buffer_state (void );

static void HECMW_ctrlensure_buffer_stack (void );
static void HECMW_ctrl_load_buffer_state (void );
static void HECMW_ctrl_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER HECMW_ctrl_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE HECMW_ctrl_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE HECMW_ctrl_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE HECMW_ctrl_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *HECMW_ctrlalloc (yy_size_t  );
void *HECMW_ctrlrealloc (void *,yy_size_t  );
void HECMW_ctrlfree (void *  );

#define yy_new_buffer HECMW_ctrl_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        HECMW_ctrlensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            HECMW_ctrl_create_buffer(HECMW_ctrlin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        HECMW_ctrlensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            HECMW_ctrl_create_buffer(HECMW_ctrlin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *HECMW_ctrlin = (FILE *) 0, *HECMW_ctrlout = (FILE *) 0;

typedef int yy_state_type;

extern int HECMW_ctrllineno;

int HECMW_ctrllineno = 1;

extern char *HECMW_ctrltext;
#define yytext_ptr HECMW_ctrltext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up HECMW_ctrltext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	HECMW_ctrlleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 42
#define YY_END_OF_BUFFER 43
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[197] =
    {   0,
        0,    0,   43,   41,    2,    3,   41,   41,   41,   36,
       40,   38,   40,   37,   35,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   41,   41,
        2,    3,    0,    0,    0,    0,    0,   38,   37,   40,
       38,   37,   38,   40,   39,    0,   39,   39,   39,   39,
       39,   24,   26,   39,   39,   39,   30,   39,   39,   39,
        0,    0,    0,    0,    0,    0,    0,    1,    0,    0,
        0,    0,    0,    0,   38,    0,    0,   40,   38,   40,
       39,   19,   39,   39,   39,   39,   39,   39,   39,   31,
       32,   39,   39,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,   38,   39,   39,   39,   39,   39,   39,
       28,   39,   39,   34,    0,    0,    0,    0,    0,    0,
        7,    0,    0,    0,    0,   39,   20,   39,   39,   25,
       27,   39,   39,    0,    6,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   18,   21,   39,   39,
       33,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   11,   15,    0,   39,   39,   29,    0,    0,    0,
       10,   14,    0,    5,    0,   13,    0,   39,   39,    4,
        0,   12,    0,    0,   17,   39,   39,    0,   16,    9,
       22,   39,    8,   39,   23,    0

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    1,    7,    1,    1,    1,    1,    1,
        1,    1,    8,    9,   10,   11,   12,   13,   13,   14,
       13,   13,   13,   13,   13,   13,   13,   15,    1,    1,
       16,    1,    1,    1,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   26,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   26,   37,   26,   38,   26,
        1,   12,    1,    1,   39,    1,   26,   26,   26,   26,

       40,   26,   26,   26,   26,   26,   26,   26,   26,   26,
       41,   26,   26,   26,   26,   26,   26,   26,   26,   26,
       26,   26,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[42] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        2,    2,    2,    2,    3,    1,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2
    } ;

static yyconst flex_int16_t yy_base[201] =
    {   0,
        0,   36,  493,  494,   42,  494,  489,   26,   35,  494,
       39,   42,    0,   51,  494,   55,   57,   63,   65,   72,
       78,   80,   86,   91,  102,  104,  111,  117,  124,   54,
      102,  494,  461,  469,  468,  446,  460,  120,  107,    0,
      123,  134,  140,  154,  154,  160,  164,  171,  173,  178,
      183,  185,  194,  196,  201,  206,  211,  219,  221,  226,
      136,  450,  456,  451,  431,  445,  147,  494,  152,  428,
      415,  412,  419,  400,  226,  236,  164,  178,  238,  408,
      244,  249,  256,  263,  268,  275,  277,  282,  289,  294,
      301,  303,  308,  386,  377,  370,  384,  366,  361,  367,

      227,  363,  343,  256,  310,  319,  321,  326,  332,  337,
      342,  344,  349,  354,  338,  344,  246,  342,  319,  318,
      222,  328,  313,  314,  300,  359,  364,  369,  375,  377,
      383,  388,  395,  294,  272,  309,  290,  285,  273,  277,
      276,  265,  258,  249,  239,  244,  397,  402,  407,  409,
      414,  228,  230,  215,  209,  190,  187,  193,  183,  173,
      152,  494,  494,  111,  419,  421,  428,  115,  105,   92,
      494,  494,   70,  494,   64,  494,   82,  430,  436,  494,
       58,  494,   71,   50,  494,  441,  443,   48,  494,  494,
      448,  450,  494,  458,  463,  494,   69,  482,  485,   49

    } ;

static yyconst flex_int16_t yy_def[201] =
    {   0,
      196,    1,  196,  196,  196,  196,  196,  196,  196,  196,
      197,  197,  197,  197,  196,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  196,  199,
      196,  196,  196,  196,  196,  196,  196,  196,  196,  197,
      197,  197,  197,  197,  198,  200,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      199,  196,  196,  196,  196,  196,  199,  196,  199,  196,
      196,  196,  196,  196,  196,  196,  196,  197,  197,  197,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  196,  196,  196,  196,  196,  196,  196,

      196,  196,  196,  196,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196,  198,  198,  198,  198,  198,
      198,  198,  198,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196,  196,  198,  198,  198,  198,
      198,  196,  196,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  198,  198,  198,  196,  196,  196,
      196,  196,  196,  196,  196,  196,  196,  198,  198,  196,
      196,  196,  196,  196,  196,  198,  198,  196,  196,  196,
      198,  198,  196,  198,  198,    0,  196,  196,  196,  196

    } ;

static yyconst flex_int16_t yy_nxt[536] =
    {   0,
        4,    5,    6,    7,    5,    8,    4,    9,   10,   11,
       12,   13,   14,   14,    4,   15,   16,   17,   17,   18,
       17,   19,   20,   21,   22,   17,   23,   17,   24,   25,
       17,   17,   26,   17,   27,   17,   17,   17,   28,   17,
       17,   29,   30,   31,   33,   38,   31,   39,   39,   41,
       80,   42,   42,   34,   43,   43,   68,   69,   35,   36,
       37,   41,   44,   42,   42,   40,   40,   40,   40,   46,
       40,   46,   47,   40,   40,   40,   40,   46,  193,   46,
      190,   44,   40,   40,  189,   49,   46,   48,   40,   40,
       40,   40,   46,  188,   46,  185,   40,   40,   51,  184,

       46,   40,   40,   31,  183,   46,   31,   55,   52,   53,
       54,   50,   40,   40,   40,   40,   46,   38,   46,   39,
       39,   40,   40,   56,   59,   46,  182,   40,   40,   61,
       57,  196,   75,   75,  181,   43,   43,   58,   68,   69,
       76,  180,   62,   44,   41,  177,   42,   42,   60,   68,
       69,   63,   43,   43,   68,   69,   64,   65,   66,   76,
       44,   77,   44,   78,   40,   40,   79,   79,  196,   40,
       40,   40,   40,   40,   40,   40,  104,  104,  196,   44,
       81,   40,   40,   40,   40,  196,  176,  196,   40,   40,
       79,   79,  196,   40,   40,   40,   40,  196,   40,  196,

       83,   85,  175,   82,   40,   40,   40,   40,  196,  174,
      196,   40,   40,  173,   86,  196,   40,   40,   84,  172,
      196,   40,   40,   87,  171,  196,  141,   90,   88,   40,
       40,   40,   40,  196,   89,  196,   40,   40,   75,   75,
      196,  170,   92,   77,  142,   77,   76,  169,  104,  104,
       79,   79,  154,   91,   40,   40,   93,  168,  196,   40,
       40,  122,  123,  196,  164,   76,   40,   40,  104,  104,
      196,  163,  106,   40,   40,  105,  153,  196,   40,   40,
      136,  137,  196,  162,  107,   40,   40,   40,   40,  196,
      161,  196,   40,   40,  154,  108,  196,  160,  142,   40,

       40,  110,  111,  196,   40,   40,  159,  158,  196,  157,
      109,   40,   40,   40,   40,  196,  156,  196,   40,   40,
       40,   40,  196,  112,  196,  155,  152,  113,  114,   40,
       40,   40,   40,  196,  146,  196,   40,   40,  145,  144,
      196,  128,   40,   40,  143,  126,  196,   40,   40,  127,
      140,  196,   40,   40,   40,   40,  196,  139,  196,   40,
       40,  138,  129,  196,   40,   40,  130,  135,  196,   40,
       40,  131,  134,  196,   40,   40,  132,  133,  196,   40,
       40,  125,  124,  196,  149,   40,   40,   40,   40,  196,
      121,  196,  147,   40,   40,  120,  148,  196,   40,   40,

      119,  118,  196,  117,  150,   40,   40,   40,   40,  196,
      116,  196,   40,   40,  115,  151,  196,   40,   40,   40,
       40,  196,   46,  196,   40,   40,  165,  166,  196,   40,
       40,   40,   40,  196,  103,  196,  102,  167,   40,   40,
       40,   40,  196,  178,  196,  101,   40,   40,  100,  179,
      196,   40,   40,   40,   40,  196,   99,  196,   40,   40,
       40,   40,  196,  186,  196,   98,   97,  192,   40,   40,
      187,   96,  196,   40,   40,  191,   95,  196,  195,   94,
       74,   73,  194,   45,   45,   67,   67,   67,   72,   71,
       70,   32,  196,    3,  196,  196,  196,  196,  196,  196,

      196,  196,  196,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196
    } ;

static yyconst flex_int16_t yy_chk[536] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    2,    5,    8,    9,    5,    9,    9,   11,
      200,   11,   11,    8,   12,   12,   30,   30,    8,    8,
        8,   14,   12,   14,   14,   16,   16,   17,   17,   16,
      197,   17,   16,   18,   18,   19,   19,   18,  188,   19,
      184,   12,   20,   20,  183,   19,   20,   18,   21,   21,
       22,   22,   21,  181,   22,  177,   23,   23,   21,  175,

       23,   24,   24,   31,  173,   24,   31,   24,   22,   22,
       23,   20,   25,   25,   26,   26,   25,   39,   26,   39,
       39,   27,   27,   25,   26,   27,  170,   28,   28,   29,
       25,   28,   38,   38,  169,   41,   41,   25,   61,   61,
       38,  168,   29,   41,   42,  164,   42,   42,   27,   67,
       67,   29,   43,   43,   69,   69,   29,   29,   29,   38,
       43,   44,   41,   44,   45,   45,   44,   44,   45,   46,
       46,   46,   46,   46,   47,   47,   77,   77,   47,   43,
       47,   48,   48,   49,   49,   48,  161,   49,   50,   50,
       78,   78,   50,   51,   51,   52,   52,   51,   46,   52,

       49,   51,  160,   48,   53,   53,   54,   54,   53,  159,
       54,   55,   55,  158,   52,   55,   56,   56,   50,  157,
       56,   57,   57,   54,  156,   57,  121,   56,   55,   58,
       58,   59,   59,   58,   55,   59,   60,   60,   75,   75,
       60,  155,   59,   76,  121,   76,   75,  154,   76,   76,
       79,   79,  153,   58,   81,   81,   60,  152,   81,   82,
       82,  101,  101,   82,  146,   75,   83,   83,  104,  104,
       83,  145,   83,   84,   84,   81,  135,   84,   85,   85,
      117,  117,   85,  144,   84,   86,   86,   87,   87,   86,
      143,   87,   88,   88,  135,   85,   88,  142,  141,   89,

       89,   87,   88,   89,   90,   90,  140,  139,   90,  138,
       86,   91,   91,   92,   92,   91,  137,   92,   93,   93,
      105,  105,   93,   89,  105,  136,  134,   92,   93,  106,
      106,  107,  107,  106,  125,  107,  108,  108,  124,  123,
      108,  107,  109,  109,  122,  105,  109,  110,  110,  106,
      120,  110,  111,  111,  112,  112,  111,  119,  112,  113,
      113,  118,  108,  113,  114,  114,  109,  116,  114,  126,
      126,  110,  115,  126,  127,  127,  112,  113,  127,  128,
      128,  103,  102,  128,  129,  129,  129,  130,  130,  129,
      100,  130,  126,  131,  131,   99,  128,  131,  132,  132,

       98,   97,  132,   96,  132,  133,  133,  147,  147,  133,
       95,  147,  148,  148,   94,  133,  148,  149,  149,  150,
      150,  149,   80,  150,  151,  151,  149,  149,  151,  165,
      165,  166,  166,  165,   74,  166,   73,  150,  167,  167,
      178,  178,  167,  165,  178,   72,  179,  179,   71,  166,
      179,  186,  186,  187,  187,  186,   70,  187,  191,  191,
      192,  192,  191,  178,  192,   66,   65,  187,  194,  194,
      179,   64,  194,  195,  195,  186,   63,  195,  194,   62,
       37,   36,  192,  198,  198,  199,  199,  199,   35,   34,
       33,    7,    3,  196,  196,  196,  196,  196,  196,  196,

      196,  196,  196,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int HECMW_ctrl_flex_debug;
int HECMW_ctrl_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *HECMW_ctrltext;
#line 1 "../src/common/hecmw_ctrllex.l"
#line 2 "../src/common/hecmw_ctrllex.l"
#include <string.h>
#include <errno.h>
#include "hecmw_ctrllex.h"
#include "hecmw_util.h"

typedef union {
	double dval;
	char *str;
} YYSTYPE;

static YYSTYPE yylval;
static int lineno;
static int flag_header;

static void set_flag_header(int flag);
#line 668 "<stdout>"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int HECMW_ctrllex_destroy (void );

int HECMW_ctrlget_debug (void );

void HECMW_ctrlset_debug (int debug_flag  );

YY_EXTRA_TYPE HECMW_ctrlget_extra (void );

void HECMW_ctrlset_extra (YY_EXTRA_TYPE user_defined  );

FILE *HECMW_ctrlget_in (void );

void HECMW_ctrlset_in  (FILE * in_str  );

FILE *HECMW_ctrlget_out (void );

void HECMW_ctrlset_out  (FILE * out_str  );

yy_size_t HECMW_ctrlget_leng (void );

char *HECMW_ctrlget_text (void );

int HECMW_ctrlget_lineno (void );

void HECMW_ctrlset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int HECMW_ctrlwrap (void );
#else
extern int HECMW_ctrlwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( HECMW_ctrltext, HECMW_ctrlleng, 1, HECMW_ctrlout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( HECMW_ctrlin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( HECMW_ctrlin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, HECMW_ctrlin))==0 && ferror(HECMW_ctrlin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(HECMW_ctrlin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int HECMW_ctrllex (void);

#define YY_DECL int HECMW_ctrllex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after HECMW_ctrltext and HECMW_ctrlleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( HECMW_ctrlleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(HECMW_ctrltext[HECMW_ctrlleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 30 "../src/common/hecmw_ctrllex.l"


#line 854 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! HECMW_ctrlin )
			HECMW_ctrlin = stdin;

		if ( ! HECMW_ctrlout )
			HECMW_ctrlout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			HECMW_ctrlensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				HECMW_ctrl_create_buffer(HECMW_ctrlin,YY_BUF_SIZE );
		}

		HECMW_ctrl_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of HECMW_ctrltext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 197 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 494 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 32 "../src/common/hecmw_ctrllex.l"
{ lineno++; set_flag_header(0); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 33 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 34 "../src/common/hecmw_ctrllex.l"
{ lineno++; set_flag_header(0); return HECMW_CTRLLEX_NL; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 36 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(1); return HECMW_CTRLLEX_H_CONTROL; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 37 "../src/common/hecmw_ctrllex.l"
{ return flag_header ? HECMW_CTRLLEX_H_CONTROL : ' '; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 38 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(1); return HECMW_CTRLLEX_H_MESH; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 39 "../src/common/hecmw_ctrllex.l"
{ return flag_header ? HECMW_CTRLLEX_H_MESH : ' '; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 40 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(1); return HECMW_CTRLLEX_H_MESH_GROUP; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 41 "../src/common/hecmw_ctrllex.l"
{ return flag_header ? HECMW_CTRLLEX_H_MESH_GROUP : ' '; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 42 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(1); return HECMW_CTRLLEX_H_RESULT; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 43 "../src/common/hecmw_ctrllex.l"
{ return flag_header ? HECMW_CTRLLEX_H_RESULT : ' '; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 44 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(1); return HECMW_CTRLLEX_H_RESTART; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 45 "../src/common/hecmw_ctrllex.l"
{ return flag_header ? HECMW_CTRLLEX_H_RESTART : ' '; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 46 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(1); return HECMW_CTRLLEX_H_SUBDIR; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 47 "../src/common/hecmw_ctrllex.l"
{ return flag_header ? HECMW_CTRLLEX_H_SUBDIR : ' '; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 48 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(1); return HECMW_CTRLLEX_H_TET_TET2; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 49 "../src/common/hecmw_ctrllex.l"
{ return flag_header ? HECMW_CTRLLEX_H_TET_TET2 : ' '; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 51 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_ABAQUS; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 52 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_DIR; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 53 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_FEMAP; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 54 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_GEOFEM; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 55 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_HECMW_DIST; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 56 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_HECMW_ENTIRE; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 57 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_IN; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 58 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_INOUT; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 59 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_IO; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 60 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_LIMIT; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 61 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_NAME; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 62 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_NASTRAN; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 63 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_ON; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 64 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_OFF; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 65 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_OUT; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 66 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_REFINE; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 67 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_CTRLLEX_K_TYPE; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 70 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return '='; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 71 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return ','; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 73 "../src/common/hecmw_ctrllex.l"
{
				yylval.dval = atof(HECMW_ctrltext);
				set_flag_header(0);
				return HECMW_CTRLLEX_INT;
			}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 78 "../src/common/hecmw_ctrllex.l"
{
				yylval.dval = atof(HECMW_ctrltext);
				set_flag_header(0);
				return HECMW_CTRLLEX_DOUBLE;
			}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 83 "../src/common/hecmw_ctrllex.l"
{
				yylval.str = HECMW_ctrltext;
				set_flag_header(0);
				return HECMW_CTRLLEX_NAME;
			}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 88 "../src/common/hecmw_ctrllex.l"
{
				yylval.str = HECMW_ctrltext;
				set_flag_header(0);
				return HECMW_CTRLLEX_FILENAME;
			}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 93 "../src/common/hecmw_ctrllex.l"
{ set_flag_header(0); return HECMW_ctrltext[0]; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 94 "../src/common/hecmw_ctrllex.l"
{ return 0; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 96 "../src/common/hecmw_ctrllex.l"
ECHO;
	YY_BREAK
#line 1170 "<stdout>"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed HECMW_ctrlin at a new source and called
			 * HECMW_ctrllex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = HECMW_ctrlin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( HECMW_ctrlwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * HECMW_ctrltext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of HECMW_ctrllex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					HECMW_ctrlrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			HECMW_ctrlrestart(HECMW_ctrlin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) HECMW_ctrlrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 197 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 197 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 196);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					HECMW_ctrlrestart(HECMW_ctrlin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( HECMW_ctrlwrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve HECMW_ctrltext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void HECMW_ctrlrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        HECMW_ctrlensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            HECMW_ctrl_create_buffer(HECMW_ctrlin,YY_BUF_SIZE );
	}

	HECMW_ctrl_init_buffer(YY_CURRENT_BUFFER,input_file );
	HECMW_ctrl_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void HECMW_ctrl_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		HECMW_ctrlpop_buffer_state();
	 *		HECMW_ctrlpush_buffer_state(new_buffer);
     */
	HECMW_ctrlensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	HECMW_ctrl_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (HECMW_ctrlwrap()) processing, but the only time this flag
	 * is looked at is after HECMW_ctrlwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void HECMW_ctrl_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	HECMW_ctrlin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE HECMW_ctrl_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) HECMW_ctrlalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in HECMW_ctrl_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) HECMW_ctrlalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in HECMW_ctrl_create_buffer()" );

	b->yy_is_our_buffer = 1;

	HECMW_ctrl_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with HECMW_ctrl_create_buffer()
 * 
 */
    void HECMW_ctrl_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		HECMW_ctrlfree((void *) b->yy_ch_buf  );

	HECMW_ctrlfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a HECMW_ctrlrestart() or at EOF.
 */
    static void HECMW_ctrl_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	HECMW_ctrl_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then HECMW_ctrl_init_buffer was _probably_
     * called from HECMW_ctrlrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void HECMW_ctrl_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		HECMW_ctrl_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void HECMW_ctrlpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	HECMW_ctrlensure_buffer_stack();

	/* This block is copied from HECMW_ctrl_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from HECMW_ctrl_switch_to_buffer. */
	HECMW_ctrl_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void HECMW_ctrlpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	HECMW_ctrl_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		HECMW_ctrl_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void HECMW_ctrlensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)HECMW_ctrlalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in HECMW_ctrlensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)HECMW_ctrlrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in HECMW_ctrlensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE HECMW_ctrl_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) HECMW_ctrlalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in HECMW_ctrl_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	HECMW_ctrl_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to HECMW_ctrllex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       HECMW_ctrl_scan_bytes() instead.
 */
YY_BUFFER_STATE HECMW_ctrl_scan_string (yyconst char * yystr )
{
    
	return HECMW_ctrl_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to HECMW_ctrllex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE HECMW_ctrl_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n, i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) HECMW_ctrlalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in HECMW_ctrl_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = HECMW_ctrl_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in HECMW_ctrl_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up HECMW_ctrltext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		HECMW_ctrltext[HECMW_ctrlleng] = (yy_hold_char); \
		(yy_c_buf_p) = HECMW_ctrltext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		HECMW_ctrlleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int HECMW_ctrlget_lineno  (void)
{
        
    return HECMW_ctrllineno;
}

/** Get the input stream.
 * 
 */
FILE *HECMW_ctrlget_in  (void)
{
        return HECMW_ctrlin;
}

/** Get the output stream.
 * 
 */
FILE *HECMW_ctrlget_out  (void)
{
        return HECMW_ctrlout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t HECMW_ctrlget_leng  (void)
{
        return HECMW_ctrlleng;
}

/** Get the current token.
 * 
 */

char *HECMW_ctrlget_text  (void)
{
        return HECMW_ctrltext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void HECMW_ctrlset_lineno (int  line_number )
{
    
    HECMW_ctrllineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see HECMW_ctrl_switch_to_buffer
 */
void HECMW_ctrlset_in (FILE *  in_str )
{
        HECMW_ctrlin = in_str ;
}

void HECMW_ctrlset_out (FILE *  out_str )
{
        HECMW_ctrlout = out_str ;
}

int HECMW_ctrlget_debug  (void)
{
        return HECMW_ctrl_flex_debug;
}

void HECMW_ctrlset_debug (int  bdebug )
{
        HECMW_ctrl_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from HECMW_ctrllex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    HECMW_ctrlin = stdin;
    HECMW_ctrlout = stdout;
#else
    HECMW_ctrlin = (FILE *) 0;
    HECMW_ctrlout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * HECMW_ctrllex_init()
     */
    return 0;
}

/* HECMW_ctrllex_destroy is for both reentrant and non-reentrant scanners. */
int HECMW_ctrllex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		HECMW_ctrl_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		HECMW_ctrlpop_buffer_state();
	}

	/* Destroy the stack itself. */
	HECMW_ctrlfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * HECMW_ctrllex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *HECMW_ctrlalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *HECMW_ctrlrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void HECMW_ctrlfree (void * ptr )
{
	free( (char *) ptr );	/* see HECMW_ctrlrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 96 "../src/common/hecmw_ctrllex.l"



static void
set_flag_header(int flag)
{
	flag_header = flag ? 1 : 0;
}


int
HECMW_ctrllex_get_lineno(void)
{
	return lineno;
}


double
HECMW_ctrllex_get_number(void)
{
	return yylval.dval;
}


char *
HECMW_ctrllex_get_text(void)
{
	return HECMW_ctrltext;
}


int
HECMW_ctrllex_next_token(void)
{
	return HECMW_ctrllex();
}


int
HECMW_ctrllex_next_token_skip(int skip_token)
{
	int token;
	while((token = HECMW_ctrllex())) {
		if(token != skip_token) break;
	}
	return token;
}


int
HECMW_ctrllex_set_input(FILE *fp)
{
	static int first = 1;
	if(fp == NULL) return -1;
	if(first) {
		HECMW_ctrlin = fp;
		first = 0;
	} else {
		HECMW_ctrlrestart(fp);
	}
	lineno = 1;
	return 0;
}


int
HECMW_ctrllex_skip_line(void)
{
	int token;
	while((token = HECMW_ctrllex_next_token())) {
		if(token == HECMW_CTRLLEX_NL) break;
	}
	return token;
}


int
HECMW_ctrllex_unput_token(void)
{
	char *p = HECMW_ctrltext;
	while(*p) {
		if(*p == '\n') {
			lineno--;
		}
		p++;
	}
	yyless(0);
	return 0;
}


int
HECMW_ctrlwrap(void)
{
	return 1;
}

